@@ -3,9 +3,10 @@ function(object, ...) {
 
 	attr <- attributes(object)
 	cat("CROSSBASIS FUNCTIONS\n")
-	cat("Observations:",nrow(object),"\n")
-	cat("Range:",attr$range[1],",",attr$range[2],"\n")
-	cat("Total df:",attr$crossdf,"\n")
+	cat("observations:",nrow(object),"\n")
+	if(attr$group>1) cat("groups:",attr$group,"\n")
+	cat("range:",attr$range[1],",",attr$range[2],"\n")
+	cat("total df:",attr$crossdf,"\n")
 	cat("maxlag:",attr$maxlag,"\n")
 
 	cat("\nBASIS FOR VAR:\n")
